.. meta::
   :google-site-verification: kxE4d_wW0ikuxlKuVCgIxNZT81VDOxKWJ7R9mbTnvKA



Fake Convergence Beam Electron Diffraction (FakeCBED)
=====================================================

``fakecbed`` is a Python library for generating quickly images that imitate
convergent beam electron diffraction patterns.

The source code can be found in the `fakecbed GitHub repository
<https://github.com/mrfitzpa/fakecbed>`_.



Instructions for installing and uninstalling ``fakecbed``
---------------------------------------------------------

For instructions on installing the ``fakecbed`` library, see the
:ref:`installation_instructions_sec` page.


     
Learning how to use ``fakecbed``
--------------------------------

For those new to the ``fakecbed`` library, it is recommended that they take a
look at the :ref:`examples_sec` page, which contain code examples that show how
one can use the ``fakecbed`` library. While going through the examples, readers
can consult the :ref:`reference_guide_sec` to understand what each line of code
is doing.



Contents
--------

.. toctree::
   :maxdepth: 6
   :numbered:

   Home <self>
   INSTALL
   Reference <_autosummary/fakecbed>
   examples
   literature
   license


   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
